@@ -1,15 +1,11 @@
 #!/usr/bin/env python
 
-"""
-Extract useful information from a VCARD file.
-
-
-"""
-
 import time
 import argparse
 import collections
 
+from . import docSplit, version, usage
+
 def __passOne(handle):
     """
     Do the initial parsing of a VCARD file, mainly glueing lines togeter and
@@ -156,7 +152,8 @@ def vcard(handle):
 
     event = vCard["VCALENDAR"][0]["VEVENT"][0]
 
-    print "Organiser: %s" % event["ORGANIZER"][0]["CN"]
+    if event["ORGANIZER"]:
+        print "Organiser: %s" % event["ORGANIZER"][0]["CN"]
     print "Attendees:"
     for i in event["ATTENDEE"]:
         print "  %s" % i["CN"]
@@ -167,25 +164,28 @@ def vcard(handle):
         parseTime(event["DTEND"][0]["VALUE"])))
 
     print "Location: %s" % event["LOCATION"][0]["VALUE"]
-    print "Description:\n" 
+    print "Description:\n"
     if not event["DESCRIPTION"]:
         if event["VALARM"]:
             print replaceAll(event["VALARM"][0]["DESCRIPTION"][0]["VALUE"],
                 descriptionReplace)
     else:
         print replaceAll(event["DESCRIPTION"][0]["VALUE"], descriptionReplace)
+
+    if event["COMMENT"]:
+        print "Comment:\n%s" % replaceAll(event["COMMENT"][0]["VALUE"],
+            descriptionReplace)
 #vcard
 
 def main():
     """
     Main entry point.
     """
-    usage = __doc__.split("\n\n\n")
     parser = argparse.ArgumentParser(
         formatter_class=argparse.RawDescriptionHelpFormatter,
         description=usage[0], epilog=usage[1])
-
     parser.add_argument("input", metavar="INPUT", type=argparse.FileType("r"))
+    parser.add_argument('-v', action="version", version=version(parser.prog))
 
     arguments = parser.parse_args()
 
